@@ -21,10 +21,10 @@
 seeds = "https://ubuntu-archive-team.ubuntu.com/seeds/"
 seeds_bzr = "http://bazaar.launchpad.net/~ubuntu-core-dev/ubuntu-seeds/"
 seeds_git = "git://git.launchpad.net/~ubuntu-core-dev/ubuntu-seeds/+git/"
-release = "ubuntu.mantic"
+release = "ubuntu.questing"
 
 # If we need to download Packages.gz and/or Sources.gz, where do we get
 # them from?
 mirror = "http://archive.ubuntu.com/ubuntu/"
-dist = "mantic"
+dist = "questing"
 arch = "amd64"
